#pragma once
/*
This .h applies to Qubio.cpp and several view .cpp files which do not have separate .h files.

Qubio.cpp - Main window construction and application setup 
VwSession - Session Dialogue 
VwConfigSession - Session configuration (modal)
VwQUBIOSettings - Default Settings for new sessions
VwConfigHardware - Configure N.I. Hardware usage
VwProtocol - Describe output waveforms
VwAcqNote - Acquisition  notes - small dialogue with time and note text only.
VwGainTable - Table of mappings from aplifier generated amperage to gain setting 
*/

//------------------------------------- In QUBIO.cpp
extern CConfigurations g_oCfgs;		

extern HBITMAP g_hbUpdate[2];
extern HBITMAP g_hbPlay[3];
extern HBITMAP g_hbSynch[2];
extern HBITMAP g_hbStop[3];
extern HBITMAP g_hbLoop[3];
extern HBITMAP g_hbRecord[2];
extern HBITMAP g_hbDraw[3];
extern HBITMAP g_hbScan[2];
extern HBITMAP g_hbTimeSep[2];
extern HBITMAP g_hbPage;

extern HFONT g_fntSS8;

//HINSTANCE GetInstance( );

const UINT WM_ACQNOTE_NEW = WM_USER+100;

HWND OpenConfigView( const char * pchWindowName ) ;
HWND OpenSessionView( const char * pchWindowName ) ; 
HWND OpenProtocolView( const char * pchWindowName ) ;
HWND OpenDigitalProtocolView( const char * pchWindowName ) ;
void OnGainTableUpdated( bool bNoSave=false );
void OnHardwareConfigUpdated( bool bNoSave=false );
void OnFeedbackUpdated( bool bNoSave=false );
void OnQuickSessionsUpdated();
 
const int IDM_GAINTABLE = WM_USER+200;		// constants for GainTable dynamic menu 
const int IDM_HARDWARECONFIG = WM_USER+300;		// constants for HardwareConfig dynamic menu 
const int IDM_FEEDBACKCONFIG = WM_USER+400;		// constants for feedback config dynamic menu 
const int IDM_QUICKSESSION = WM_USER+500;      // re-open recent session dynamic menu

//------------------------------------- In VwSession 
// Acquisition session dialogue

const UINT WM_SESSION_LOAD = WM_USER + 1;	// notify session to load a file
const UINT WM_SESSION_NEW = WM_USER + 2;	// notify session to create a new session
const UINT WM_DATA_UPDATE = WM_USER + 3;	// notify session new data is available
const UINT WM_ACQPOLLSTOP = WM_USER + 4;		// notify session poller has completed
const UINT WM_GENPOLLSTOP = WM_USER + 5;		// notify session poller has completed
BOOL CALLBACK SessionDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

	// Mode of operation for Acq, Gen, DigAcq, DigGen.
	// Generate once or continuous mode are bitwise or'd with the line number for 
	// analog and with 2**iLine for digital ( i.e. line 9 only = bits 0000001000000000 ).
const int MODE_NULL =0x10000;	// for passing "do not change mode" 
const int MODE_SYNCH=0x20000;	// for synchronized acq, gen, ... 
const int MODE_IDLE =0x3000;	// Idle / Inactive 

const int MODE_ACQPLAY	=0x4000;// Acquisition play ( to screen only ) 
const int MODE_ACQRECORD=0x5000;// Acquisition record ( to screen and file ) 

const int MODE_GENONCE	=0x6000;// Generate once
const int MODE_GENCONT	=0x7000;// Generate Continuously, or'd with acq panel # 
const int MODE_GENALL	=0x8000;// Generate all, once or continuous depends on each []Repeat checkbox setting.

//------------------------------------- In VwConfigSession.cpp
// Configuration of an acquisition session - buffers, filenames, ...
//-- edit lengths
const int CFGSESSION_BUFSIZEMAXLEN = 8;
const int CFGSESSION_RATEMAXLEN = 7;
const int CFGSESSION_PERPIXMAXLEN = 5;
//-- messages
const UINT WM_CONFIGSESSION_LOAD = WM_USER + 1;
const UINT WM_CONFIGSESSION_NEW = WM_USER + 2;
BOOL CALLBACK ConfigSessionDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwQUBIOSettings.cpp
// Configuration of overall program
//-- dialog callback
BOOL CALLBACK QUBIOSettingsDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwConfigHardware.cpp
// Configure Hardware dialogue - selection of device and channels available to a session
const UINT WM_CONFIG_EDIT = WM_USER + 1;
const UINT WM_CONFIG_NEW = WM_USER + 2;
//-- edit lengths
const int CONFIG_NAME_LENGTH = 25;
const int CONFIG_SCALING_LENGTH = 16;

const int DOMODE_DISABLED=0;
const int DOMODE_AUTO=1;
const int DOMODE_MANUAL=2;
const int DOMODE_PROTOCOL=3;
const int DOMODE_INPUT=4;

//-- dialog callback
BOOL CALLBACK ConfigDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwProtocol 
// Dialog for Constuction of a generation waveform
const UINT WM_PRO_LOAD = WM_USER + 1;
const UINT WM_PRO_NEW = WM_USER + 2;
const UINT WM_PRO_GEN = WM_USER + 3;
BOOL CALLBACK ProtocolDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwDigitalProtocol 
const UINT WM_DIGPRO_LOAD = WM_USER + 1;
const UINT WM_DIGPRO_NEW = WM_USER + 2;
BOOL CALLBACK DigitalProtocolDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwProtocolCalc 
//LRESULT CALLBACK ProCalcDlgProc(HWND hDlg, UINT message, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwAcqNote
const UINT WM_ACQNOTESETUP = WM_USER + 1;
const UINT WM_ACQNOTESETUP2 = WM_USER + 12;
const UINT WM_ACQNOTE_SESSIONDESTROYED = WM_USER + 2;
BOOL CALLBACK AcqNoteDlgProc(HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwGainTable.cpp
BOOL CALLBACK GainTableDlgProc( HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwFeedback.cpp
BOOL CALLBACK FeedbackDlgProc( HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

//------------------------------------- In VwPulseProtocolGen.cpp
void OpenVwGenPulseProtocol( HWND hDlg );
BOOL CALLBACK VwGenPulseProtocolDlgProc( HWND hDlg, UINT iMsg, WPARAM wParam, LPARAM lParam);

